@@ -18,9 +18,9 @@
 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 	*/
 
-	// ================================== //
-	// settings.php - German (formal) 1.2 //
-	// ================================== //
+	// =========================== //
+	// settings.php - German (Sie) //
+	// =========================== //
 	//
 	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
 
@@ -28,5 +28,6 @@
 	$charset = "utf-8";
 	$language = "German / Deutsch (Sie)";
 	$language_short = "de";
-	$language_version = "1.3";
+	$language_version = "1.6";
+	$language_author = "J&uuml;rgen Gr&uuml;neisl";
 ?>
