@@ -18,9 +18,9 @@
 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 	*/
 
-	// ============================ //
-	// lang_admin.php - Italian 1.1 //
-	// ============================ //
+	// ======================== //
+	// lang_admin.php - Italian //
+	// ======================== //
 	//
 	// This language file was translated by Christian Castelli alias VooDoo (voodoo81people@gmail.com) 
 	//
@@ -34,8 +34,18 @@
 	$lang['save'] = "Salva";
 	$lang['administrator'] = "amministratore";
 	$lang['moderator'] = "moderatore";
+	$lang['gravatar_type_0'] = "Standard";
+	$lang['gravatar_type_1'] = "Mistery-Man";
+	$lang['gravatar_type_2'] = "Identicon";
+	$lang['gravatar_type_3'] = "Monsterid";
+	$lang['gravatar_type_4'] = "Wavatar";
+	$lang['gravatar_type_5'] = "Retro";
+	$lang['gravatar_position_left'] = "A sinistra";
+	$lang['gravatar_position_right'] = "a destra";
+	$lang['timestamp'] = "Timestamp";
+	$lang['quote'] = "Citazione di";
 
-	// login.php
+	// login.inc.php
 	$lang['title'] = "MGB {MGB_VERSION} - Amministrazione";	
 	$lang['login_username'] = "Username:";
 	$lang['login_password'] = "Password:";
@@ -61,53 +71,54 @@
 	$lang['errormessage11'] = "Questo username o quest'indirizzo eMail sono già in uso.";
 	$lang['errormessage12'] = "La chiave non è valida o già scaduta.";
 	$lang['errormessage13'] = "E' già stata richiesta una nuova password per questo account.<br>Non è possibile richiederne una nuova finchè la nuova password non è utilizzata o scaduta.";
-	$lang['errormessage14'] = "eMail could not be sent. Maybe there's a problem with the mailserver.";
-	$lang['errormessage15'] = "Versionnumber could not be retrieved cause <a href=\"http://php.net/manual/en/function.fopen.php\">fopen()</a> is deactivated on your server.<br>Please contact your host to solve the problem.<br><br>In the meantime you can check the newest version on http://www.m-gb.org/.";
+	$lang['errormessage14'] = "eMail non può essere inviata. Forse c'è un problema con il mailserver.";
+	$lang['errormessage15'] = "Il numero della versione non può essere recuperato perchè <a href=\"http://php.net/manual/en/function.fopen.php\">fopen()</a> è disattivata sul tuo server.<br> Contatta il tuo host provider per risolvere il problema.<br><br>Nel frattempo puoi dare un'occhiata alla nuova versione su http://www.m-gb.org/.";
+	$lang['errormessage16'] = "La password fornita è troppo corta. Password sicure dovrebbero avere almeno ".$settings['password_min_length']." caratteri.";
 
 	// general strings
 	$lang['back_to_mainpage'] = "Torna alla pagina principale";
 	$lang['back'] = "Indietro";
-	$lang['go'] = "Go!";
+	$lang['go'] = "Vai!";
 	$lang['entry'] = "Post";
 	$lang['entries'] = "Post";
 	$lang['no_entries'] = "Non ci sono post disponibili.";
 	$lang['no_deactivated_entries'] = "Non ci sono post diattivati.";
 	$lang['no_activated_entries'] = "Non ci sono post attivati";
-	$lang['no_spam_entries'] = "No spam entries available.";
+	$lang['no_spam_entries'] = "Non sono presenti post marcati come spam";
 	$lang['entries_on_pages'] = "Post in {PAGES} pagine";
-	$lang['page_first'] = "First page";
+	$lang['page_first'] = "Prima pagina";
 	$lang['page_first_symbol'] = "&laquo;";
 	$lang['page_forwards'] = "Sfoglia una pagina in avanti";
 	$lang['page_forwards_symbol'] = "&rsaquo;";
-	$lang['page_last'] = "Last page";
+	$lang['page_last'] = "Ultima pagina";
 	$lang['page_last_symbol'] = "&raquo;";
 	$lang['page_backwards'] = "Sfoglia una pagina indietro";
 	$lang['page_backwards_symbol'] = "&lsaquo;";
-	$lang['captcha_method_code'] = "Securitycode";
-	$lang['captcha_method_math'] = "Mathematic";
+	$lang['captcha_method_code'] = "Codice di sicurezza";
+	$lang['captcha_method_math'] = "Matematica";
 	$lang['activate_entry'] = "Attiva questo post";
 	$lang['deactivate_entry'] = "Disattiva questo post";
 	$lang['delete_entry'] = "Cancella questo post";
-	$lang['mark_as_spam'] = "Mark as spam";
-	$lang['nospam_entry'] = "Mark entry as 'no spam' and activate it";
-	$lang['nospam_deactivate_entry'] = "Mark entry as 'no spam' but let it deactivated";
+	$lang['mark_as_spam'] = "Marca come spam";
+	$lang['nospam_entry'] = "Marca come 'non spam' e attivalo";
+	$lang['nospam_deactivate_entry'] = "Marca come 'non spam' ma lascialo disattivato";
 	$lang['active'] = "Questo post è stato attivato nel guestbook";
 	$lang['inactive'] = "Questo post non è stato attivato nel guestbook";
 	$lang['edit_entry'] = "Edita il post";
-	$lang['do_nothing'] = "Do nothing ...";
-	$lang['delete_whole_spam'] = "Delete all spam entries";
-	$lang['mark_all_no_spam_deactivate'] = "Mark all entries as 'no spam' and activate it";
-	$lang['mark_all_no_spam_activate'] = "Mark all entries as 'no spam' but let them deactivated";
-	$lang['mark_all_as_spam'] = "Mark all entries as spam";
-	$lang['activate_all_entries'] = "Activate all entries";
-	$lang['deactivate_all_entries'] = "Deactivate all entries";
-	$lang['delete_all_entries'] = "Delete all entries";
+	$lang['do_nothing'] = "Non fare nulla ...";
+	$lang['delete_whole_spam'] = "Cancella tutti i post marcati come spam";
+	$lang['mark_all_no_spam_deactivate'] = "Marca tutti i post come 'non spam' e attivali";
+	$lang['mark_all_no_spam_activate'] = "Marca tutti i post come 'non spam' ma lasciali disattivati";
+	$lang['mark_all_as_spam'] = "Marca tutti i post come spam";
+	$lang['activate_all_entries'] = "Attiva tutti i post";
+	$lang['deactivate_all_entries'] = "Disattiva tutti i post";
+	$lang['delete_all_entries'] = "Cancella tutti i post";
 
 	$lang['sendmail_user_notification_title'] = "Il tuo post presso {DOMAIN} e\' stato attivato";
 	$lang['sendmail_user_comment_title'] = "al tuo post presso {DOMAIN} è stato fatto un commento";
 	$lang['sendmail_adduser_title'] = "I tuoi dati utenti presso {DOMAIN}";
 	$lang['sendmail_adduser_text'] = "Sei stato registrato con successo presso {DOMAIN} dall'amministratore. Qui di seguito i tuoi dati utente:<br /><br />Username: {ADDUSER_NAME}<br />Password: {ADDUSER_PASSWORD}<br /><br />Puoi loggarti qui: {ADDUSER_URL}";
-	$lang['sendmail_admin_text'] = "{NAME} ha lasciato un nuovo post nel guestbook.<br /><br />Data: {DATE}<br />Ora: {TIME}<br /><br />---<br />{MESSAGE}<br />---";
+	$lang['sendmail_admin_text'] = "{NAME} ha lasciato un nuovo post nel guestbook.<br /><br />Data: {DATE}<br />Ora: {TIME}<br /><br />---<br />{MESSAGE}<br />---<br /><br />{URL_TO_GB}";
 	$lang['sendmail_user_text'] = "Ciao {NAME},<br /><br />grazie per aver postato nel mio guestbook. Attivero\' il tuo post il prima possibile,non appena ci avrò dato un\'occhiata.";
 	$lang['sendmail_user_notification_text'] = "Ciao {NAME},<br /><br />Il tuo post presso {DOMAIN} e\' stato or ora attivato. Lo puoi vedere qui: {URL_TO_GB}";
 	$lang['sendmail_comment_text'] = "Ciao {NAME},<br /><br />riguardo al tuo post<br /><br />---<br />{MESSAGE}<br />---<br /><br />è stato inserito un commento. Puoi vederlo qui: {URL_TO_GB}";
@@ -123,23 +134,27 @@
 	$lang['deactivate'] = "Disattiva il post";
 	$lang['delete'] = "Cancella il post";
 	$lang['edit'] = "Modifica il post";
-	$lang['spam'] = "Spam entries";
+	$lang['spam'] = "Spam";
+	$lang['edit_smilies'] = "Modifica smilies";
 	$lang['users'] = "Amministrazione utenti";
-	$lang['stats'] = "Statistics";
+	$lang['stats'] = "Statistiche";
 	$lang['license'] = "Licenza";
 	$lang['forum'] = "Forum";
 	$lang['bugreport'] = "Riporta un bug";
 	$lang['version'] = "Versione";
 	$lang['manual'] = "Documentazione";
+	$lang['to_guestbook'] = "Vai al guestbook";
 	$lang['paypal'] = "Se ti piace MGB e pensi sia utile, puoi considerare di effettuare una donazione per supportare il suo sviluppo futuro.";
 
 	// settings.inc.php
 	$lang['edit_caption_general'] = "Settaggi generali";
 	$lang['edit_caption_look'] = "Look &amp; feel";
+	$lang['edit_caption_bbcodes'] = "BBCodes";
+	$lang['edit_caption_smilies'] = "Emoticons";
 	$lang['edit_caption_gravatars'] = "Supporto gravatar";
 	$lang['edit_caption_security'] = "Sicurezza";
 	$lang['edit_caption_email'] = "eMail";
-	$lang['edit_save_message'] = "Saved settings successfull.";
+	$lang['edit_save_message'] = "Salvataggio settaggi avvenuto con successo.";
 	$lang['edit_title'] = "Titolo:";
 	$lang['edit_h_author'] = "Autore:";
 	$lang['edit_h_domain'] = "Dominio:";
@@ -162,27 +177,46 @@
 	$lang['edit_language_path'] = "File del linguaggio:";
 	$lang['edit_badwords'] = "Parolacce:";
 	$lang['edit_bbcode'] = "Codice BB:";
-	$lang['edit_smileys'] = "Smileys:";
+	$lang['edit_allow_img_tag'] = "IMG-Tag:";
+	$lang['edit_max_img_width'] = "Larghezza massima dell'immagine::";
+	$lang['edit_max_img_height'] = "Altezza massima dell'immagine:";
+	$lang['edit_center_img'] = "Mostra le immagini centrate:";
+	$lang['edit_allow_flash_tag'] = "FLASH-Tag:";
+	$lang['edit_max_flash_width'] = "Larghezza massima oggetti flash:";
+	$lang['edit_max_flash_height'] = "Altezza massima oggetti flash:";
+	$lang['edit_center_flash'] = "Mostra gli oggetti flash centrati:";
+	$lang['edit_smileys'] = "Smilies:";
+	$lang['edit_smileys_break'] = "Ritorno a capo per lo smiley:";
+	$lang['edit_smileys_order'] = "Ordinamento degli smilies:";
 	$lang['edit_captcha'] = "Captcha:";
-	$lang['edit_captcha_method'] = "Sort of captcha:";
+	$lang['edit_captcha_method'] = "Metodo captcha:";
+	$lang['edit_captcha_coords'] = "Coordinate captcha:";
+	$lang['edit_captcha_color'] = "Colore captcha:";
+	$lang['edit_captcha_angle'] = "Angolo captcha:";
 	$lang['edit_akismet_plugin'] = "Akismet-Plugin:";
 	$lang['edit_akismet_api'] = "Akismet API Key:";
-	$lang['edit_akismet_mark_as_spam'] = "Spam marking:";
+	$lang['edit_akismet_mark_as_spam'] = "Marcatura spam:";
 	$lang['edit_time_lock'] = "Sign lock:";
-	$lang['edit_time_lock_value'] = "Minimum time for sign lock:";
-	$lang['edit_time_lock_maxtime'] = "Maximum time for sign lock:";
+	$lang['edit_time_lock_value'] = "Tempo minimo per il sign lock:";
+	$lang['edit_time_lock_maxtime'] = "Tempo massimo per il sign lock:";
 	$lang['edit_user_notification'] = "Notifica utente:";
 	$lang['edit_user_show_email'] = "Usermail presso il guestbook:";
 	$lang['edit_session_timeout'] = "timeout della sesseione:";
+	$lang['edit_password_min_length'] = "Lunghezza minima per le passwords:";
 	$lang['edit_moderated'] = "Guestbook moderato:";
 	$lang['edit_entries_per_page'] = "Post per pagina:";
 	$lang['edit_entries_order'] = "Ordine dei post:";
+	$lang['edit_entries_order_asc_desc'] = "Sequenza d'ordinamento:";
+	$lang['edit_entries_numbering'] = "Sequenza di numerazione:";
 	$lang['edit_spam_protection'] = "Protezione eMail contro lo spam :";
 	$lang['edit_ipblocker'] = "IP-Blocker:";
 	$lang['edit_wordwrap'] = "Ritorno a capo automatico:";
 	$lang['edit_dateform'] = "Formato della data:";
 	$lang['edit_gravatar_show'] = "Mostra gravatars:";
 	$lang['edit_gravatar_rating'] = "Votazione gravatar:";
+	$lang['edit_gravatar_type'] = "Gravatar non registrati:";
+	$lang['edit_gravatar_size'] = "Dimensione gravatar:";
+	$lang['edit_gravatar_position'] = "Posizione:";
 
 	$lang['edit_expl_title'] = "Titolo del guestbook.";
 	$lang['edit_expl_h_author'] = "I nomi degli autori della pagina internet.";
@@ -203,34 +237,54 @@
 	$lang['edit_expl_template_path'] = "Il template che verrà usato.";
 	$lang['edit_expl_template_style_path'] = "Lo stile desiderato del template. Non puoi selezionarlo fintanto che il template non viene caricato.";
 	$lang['edit_expl_iconset_path'] = "Il set grafico desiderato che fornisce icone, smileys e sfondi per i captcha indipendenti dal template udsato.";
-	$lang['edit_expl_language_path'] = "Il linguaggio usato. Se hai problemi con le umlauts o altri caratteri, potrebbe esser d'aiuto cpassare da uft-8 a iso-8859-15 (latin9) o voceversa.";
+	$lang['edit_expl_language_path'] = "Il linguaggio usato.<br><br><b>ATTENZIONE:</b> dalla versione <b>0.6.5</b> le lingue nel set di caratteri latin9 (iso-8859-15) <b>non sono più</b> supportate! Se trovi dei problemi, quali variabili mancanti, campi di testo vuoti e così via, per favore cambia il set di caratteri  in uno basato su utf-8. Inoltre rimuovi ogni linguaggio basato su latin9 dalla cartella ''language''.<br><br>Dopo di che è possibile risolvere ogni problema di caratteri speciali o accentati eseguendo ''convert_ansi.php'' nella cartella ''install''.";
+	$lang['edit_expl_language_charset'] = "Set di caratteri:";
 	$lang['edit_expl_badwords'] = "Fornisci qui le parole indesiderate separate da una virgola, le quali saranno rimpiazzate da asterischi (*). Lascia vuoto per non attivare la funzione.";
 	$lang['edit_expl_bbcode'] = "Permette all'utente di formattare il testo.";
+	$lang['edit_expl_allow_img_tag'] = "L'implementazione delle immagini in un post del guestbook contiene alcuni rischi di sicurezza. Le immagini potrebbero contenere malware o un utente potrebbe fornire un'immagine che viola i termini legali. Inoltre immagini molto grosse riducono la velocità di caricamento del guestbook.<br><br><b>Il tag IMG dovrebbe venir attivato solamente se il guestbook è moderato.</b>";
+	$lang['edit_expl_max_img_width'] = "Definisce la massima larghezza di un'immagine.<br><br><b>ATTENZIONE: disponibile solo quando <a href='http://de2.php.net/manual/en/function.getimagesize.php' target='_blank' title='php.net'>getimagesize();</a> funziona o se le dimensioni vengono fornite al tag [img] in questo modo -> [img=width,height]URL dell'immagine[[/img]).</b>";
+	$lang['edit_expl_max_img_height'] = "Definisce la massima altezza di un'immagine.<br><br><b>ATTENZIONE: disponibile solo quando <a href='http://de2.php.net/manual/en/function.getimagesize.php' target='_blank' title='php.net'>getimagesize();</a> funziona o se le dimensioni vengono fornite al tag [img] in questo modo -> [img=width,height]URL dell'immagine[/img]).</b>";
+	$lang['edit_expl_center_img'] = "Definisce se i tag [img] delle immagini vengono mostrati centrati.";
+	$lang['edit_expl_allow_flash_tag'] = "Permette all'utente di inserire video flash, come se provenissero da Youtube.<br><br><b>Per ragioni di sicurezza il BBCode per i video flash dovrebbe venir attivato solamente se il guestbook è moderato.</b>";
+	$lang['edit_expl_max_flash_width'] = "Definisce la massima larghezza di un video flash.";
+	$lang['edit_expl_max_flash_height'] = "Definisce la massima altezza di un video flash.";
+	$lang['edit_expl_center_flash'] = "Definisce se i tag video [flash] vengono mostrati centrati.";
 	$lang['edit_expl_smileys'] = "Permette all'utente di aggiungere smileys.";
+	$lang['edit_expl_smileys_break'] = "Definisce dopo quanti smilies c'è un ritorno a capo nella lista degli smilies in ''newentry.php''. Può esser d'aiuto se vengono usati molti smilies.";
+	$lang['edit_expl_smileys_order'] = "Indica come vengono ordinati gli smilies. Crescente o descrescente.";
 	$lang['edit_expl_captcha'] = "Se attivato un codice di verifica deve essere immesso per aggiungere un nuovo post o spedire una mail ad un utente.";
-	$lang['edit_expl_captcha_method'] = "You can choose between a securitycode, or a mathematic formula the user has to solve.";
-	$lang['edit_expl_akismet_plugin'] = "Akismet is an external anti-spam-service, that checks new entries on spam. The akismet-plugin can be downloaded at <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet Plugin'>http://www.m-gb.org/</a>.<b>ATTENTION: With using the plugin 'akismet' you accept the transmission of data to a server in the United States of America. If you don't comply with that circumstance you MUST NOT USE 'Akismet'. Also your users have to agree with that if you activate the plugin.</b>";
-	$lang['edit_expl_akismet_api'] = "In order to use Akismet you need an <a href='http://akismet.com/signup/#free' title='Akismet API Key'>API Key</a>. Sign in for free and enter it here after registration.";
-	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version'>Akismet is installed!</span>";
-	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version'>Akismet is NOT installed!</span>";
-	$lang['edit_expl_akismet_mark_as_spam'] = "If this option is enabled, positive Akismet entries are marked as spam and appear in the administration panel so you can check them for yourself and decide what to do with.";
-	$lang['edit_expl_time_lock'] = "If this option is enabled, a counter that prevents sending the formular too fast runs in the background of a new entry. If the user is too fast with his entry, a message appears that tells him how many seconds he have to wait, until he can sign the guestbook.";
-	$lang['edit_expl_time_lock_value'] = "Minimum time a user has to wait to send the formular.";
-	$lang['edit_expl_time_lock_maxtime'] = "Maximum time a user has the chance to sign the guestbook. If it takes too long, the counter restarts.";
+	$lang['edit_expl_captcha_method'] = "Puoi scegliere fra un codice di sicurezza o una formula matematica che l'utente deve risolvere.";
+	$lang['edit_expl_captcha_coords'] = "Definisce le coordinate dove il testo inizia ad esser disegnato nell'immagine di sfondo. Il punto d'origine è <b>l'angolo sinistro più basso del primo carattere</b>.";
+	$lang['edit_expl_captcha_color'] = "Definisce il colore del testo del captcha. Il valore dev'essere il formato HTML senza '#'.<br><br><b>Giusto: <span class='newer_version'>505050</span><br>Sbagliato: <span class='old_version'>#505050</span></b>";
+	$lang['edit_expl_captcha_angle'] = "Entrambi questi valori definiscono l'insieme dei gradi per la renderizzazione casuale del captcha.<br><br>The left value has to be <b>lower</b> than the right value.";
+	$lang['edit_expl_akismet_plugin'] = "Akismet è un servizio esterno anti-spam, che controlla i post alla ricerca di spam. Il plugin akismet può essere scaricato da <a href='http://www.m-gb.org/index.php?id=download_gb' title='Scarica Akismet Plugin'>http://www.m-gb.org/</a>.<br><br><b>ATTENZIONE: usando il plugin 'akismet' accetti la trasmissione di dati verso server negli Stati Uniti d'America. Se non accetti queste condizioni NON DEVI USARE 'Akismet'. Inoltre anche i tuoi utenti devono accettare queste condizioni se attivi il plugin.</b>";
+	$lang['edit_expl_akismet_api'] = "Per usare Akismet hai bisogno dell'<a href='http://akismet.com/signup/#free' title='Akismet API Key'>API Key</a>. Registrati gratuitamente e inseriscila qui dopo la registrazione.";
+	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version' style='font-size: 14px;'>Akismet è installato!</span>";
+	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version' style='font-size: 14px;'>Akismet NON è installato!</span>";
+	$lang['edit_expl_akismet_mark_as_spam'] = "Se quest'opzione è abilitata, i post positivi secondo Akismet sono marcati come spam e appariranno nel pannello amministrativo così che tu possa controllarli e decidere cosa farne.";
+	$lang['edit_expl_time_lock'] = "Se quest'opzione è abilitata, si attiva in background un contatore che previene l'invio della frase troppo velocemente. Se l'utente è troppo veloce nel postare, appare un messaggio che lo invita ad attendere per alcuni secondi, fintanto che potrà firmare il guestbook.";
+	$lang['edit_expl_time_lock_value'] = "Tempo minimo che l'utente deve aspettare per inviare la frase.";
+	$lang['edit_expl_time_lock_maxtime'] = "Tempo massimo consentito all'utente per firmare il guestbook. Se ci mette troppo tempo, il contatore ricomincia.";
 	$lang['edit_expl_user_notification'] = "Permette all'utente di decidere se sarà avvertito via email se il suo post sarà attivato.";
 	$lang['edit_expl_user_show_email'] = "Permette all'utente di decidere se il suo indirizzo eMail verrà mostrato nel guestbook oppure no. Se disabilita la checkbox nessuno all'infuori dell'amministratore potrà spedirgli una mail.";
 	$lang['edit_expl_session_timeout'] = "Un ut3ente inattivo verrà automaticamente sloggato se questo periodo scade. Espresso in <b>secondi</b>. Il valore dev'essere maggiore o uguale a (>=) <b>60</b>.";
+	$lang['edit_expl_password_min_length'] = "Definisce la lunghezza minima delle password di Amministratori / Moderatori.";
 	$lang['edit_expl_moderated'] = "Se attivato, i post devono essere attivati per essere mostrati nel guestbook.";
 	$lang['edit_expl_entries_per_page'] = "Indica quanti post verranno mostrati per pagina. Il valore <b>non deve essere 0</b>.";
 	$lang['edit_expl_entries_order'] = "Definisce l'ordine attraverso il quale i post vengono numerati";
+	$lang['edit_expl_entries_order_asc_desc'] = "Definisce la sequenza con cui i post vengono ordinati.";
+	$lang['edit_expl_entries_numbering'] = "Definisce la sequenza con cui vengono numerati i post.<br><br><b>ATTENZIONE:</b> questo non ha niente a che fare con l'ordinamento dei post, ma solo come vengono numerati.";
 	$lang['edit_expl_spam_protection'] = "Se attivato, l'utente verrà portato ad un form dei contatti, se clicca sul simbolo della mail in un post per spedirgli una email. Per cui gli indirizzi eMail <b>NON</b> verranno mostrati direttamente.";
 	$lang['edit_expl_ipblocker'] = "Evita post multipli in serie da parte di un utente.";
 	$lang['edit_expl_wordwrap'] = "Indica il numero di caratteri dopo i quali una parola molto lunga verrà troncata. <b>0</b> per disattivare.";
 	$lang['edit_expl_dateform'] = "Il form per dire come la data verrà mostrata. La formattazione è fatta attraverso la funzione PHP <a class='admin' href='http://www.php.net/manual/en/function.date.php' title='date()' target='_blank'>date()</a>.";
 	$lang['edit_expl_gravatar_show'] = "Gravatars (Global Recognized Avatars) sono piccole immagini che verranno mostrate a fianco dei post dell'utente. Dipendono dal fatto che l'utente sia <a class=\"admin\" href=\"http://site.gravatar.com/\" target=\"_blank\" title=\"Gravatar Service\">registrato</a> con il suo indirizzo eMail a questo servizio.";
 	$lang['edit_expl_gravatar_rating'] = "Definisce a quale grado i gavatars saranno mostrati.<br><br><b>G</b> = per ogni età<br><b>PG</b> = illustrazione leggermente violenta, persone vestite provocatoriamente e gesti<br><b>R</b> = illustrazioni di violenza intensa, oscenità<br><b>X</b> = immagini a sfondo sessuale esplicito";
+	$lang['edit_expl_gravatar_type'] = "Qui puoi settare come i gravatar verranno visualizzati se le email degli utenti non sono registrate al servizio.";
+	$lang['edit_expl_gravatar_size'] = "Definisce la grandezza del gravatar in <b>pixel</b>.";
+	$lang['edit_expl_gravatar_position'] = "Mostra il gravatar a sinistra o a destra del messaggio.";
 
-	// edit.php
+	// edit.inc.php
 	$lang['ID'] = "ID:";
 	$lang['ip'] = "IP:";
 	$lang['date'] = "Data:";
@@ -247,7 +301,19 @@
 	$lang['user_show_email'] = "Mostra gli indirizzi eMail nel guestbook:";
 	$lang['comment'] = "Commenti:";
 
-	// edit_user.php
+	// smilies.inc.php
+	$lang['add_smilies_descr'] = "Qui puoi modificare o rimuovere gli smilies.<br><br>Tutti gli milies devono essere messi nella cartella <b>'images/smilies/'</b> nella directory principale del guestbook. Devi solo mettere il nome del file dentro <b>l'area di testo vuota</b> e poi cliccare <b>salva</b>.<br><br>Puoi impostare più di un segnaposto per uno smiley. Separali con una <b>virgola e uno spazio</b>. Il <b>primo</b> segnaposto  nella linea sarà utilizzato per inserire gli smiley nella textarea in ''newentry.php''.<br><br><span class='same_version'>Corretto:</span> :smile:, :), :-)<br><span class='old_version'>Sbagliato:</span> :smile:,:),:-)<br><br><b>Attenzione: se cambi gli smilies o i segnaposto esistenti già in uso in alcuni post, quest'ultimi non potranno essere più ripristinati! Dovrai modificare manualmente tutte le occorenze.</b>";
+	$lang['smiley_path'] = "Nome del file";
+	$lang['smiley_replacement'] = "Segnaposto";
+	$lang['add_new_smiley'] = "Aggiungi smiley";
+	$lang['checked_smilies'] = "Smilies controllati...";
+	$lang['delete_checked_smilies'] = "... rimuovi dalla lista, mantieni quelli non contrassegnati";
+	$lang['keep_checked_smilies'] = "... mantieni, rimuovi quelli non contrassegnati";
+	$lang['smiley_width'] = "Larghezza";
+	$lang['smiley_height'] = "Altezza";
+	$lang['smilies'] = "Smilies";
+
+	// edit_user.inc.php
 	$lang['user_is_active'] = "L'utente è attivo:";
 	$lang['r_user_type'] = "L'utente è:";
 	$lang['r_settings'] = "Cambia i settaggi:";
@@ -255,7 +321,8 @@
 	$lang['r_deactivate'] = "Disattiva i post:";
 	$lang['r_delete'] = "Cancella i post:";
 	$lang['r_edit'] = "Modifica i post:";
-	$lang['r_spam'] = "Manage spam:";
+	$lang['r_spam'] = "Gestisci spam:";
+	$lang['r_edit_smilies'] = "Modifica smilies";
 	$lang['old_password'] = "La tua password corrente:";
 	$lang['new_password_1'] = "Nuova password:";
 	$lang['new_password_2'] = "Digita di nuovo:";
@@ -276,11 +343,13 @@
 	$lang['old_version'] = "La tua versione è vecchia.<br>Si raccomanda un aggiornamento.<br><br><a href='http://www.m-gb.org/index.php?id=download_gb' class='admin' target='_blank' title='Update now'>Vai alla nuova versione</a>";
 	$lang['same_version'] = "Stai usando l'ultima versione disponibile.<br>Non si necessita di un aggiornamento.";
 	$lang['newer_version'] = "La tua versione è più recente dell'ultima versione stabile.<br>Non si necessita di un aggiornamento.";
-	$lang['new_version_available'] = "A new version is available: <a href='http://www.m-gb.org/files/latest/mgb-latest.zip' class='admin' target='_blank' title='Upgrade now!'>{LATEST_VERSION}</a>";
+	$lang['new_version_available'] = "&Egrave; disponibile una nuova versione: <a href='http://www.m-gb.org/files/latest/mgb-latest.zip' class='admin' target='_blank' title='Upgrade now!'>{LATEST_VERSION}</a>";
 
 	// lostpassword.php
 	$lang['lostpassword_mail'] = "il tuo indirizzo eMail:";
 	$lang['get_new_pw'] = "richiedi una nuova password";
 	$lang['lostpassword_success'] = "La tua richiesta è terminata. Riceverai a breve una eMail<br>con un link di conferma. cliccaci sopra per attivare la tua nuova password.";
+	$lang['lostpassword_no_success'] = "Non è stato possibile gestire la tua richiesta.  C'è stato un problema con il mailserver.";
 	$lang['lostpassword_success_created'] = "I tuoi nuovi dati di login sono stati<br>spediti via eMail.";
+	$lang['lostpassword_no_success_created'] = "Non è stato possibile gestire la tua richiesta.  C'è stato un problema con il mailserver.";
 ?>
